linux-kernel.vger.kernel.org archive mirror
 help / color / mirror / Atom feed
From: Tanjuate Brunostar <tanjubrunostar0@gmail.com>
To: gregkh@linuxfoundation.org
Cc: linux-staging@lists.linux.dev, linux-kernel@vger.kernel.org,
	outreachy@lists.linux.dev,
	Tanjuate Brunostar <tanjubrunostar0@gmail.com>
Subject: [PATCH 13/17] staging: vt6655: changed variable name: bNeedACK
Date: Tue, 25 Oct 2022 23:37:09 +0000	[thread overview]
Message-ID: <c41b74ed595c33c4d3385aa2ae638e337b26337e.1666740522.git.tanjubrunostar0@gmail.com> (raw)
In-Reply-To: <cover.1666740522.git.tanjubrunostar0@gmail.com>

change variable names bDisCRC to meet the
linux coding standard, as it says to avoid using camelCase naming
style. Cought by checkpatch

Signed-off-by: Tanjuate Brunostar <tanjubrunostar0@gmail.com>
---
 drivers/staging/vt6655/rxtx.c | 36 +++++++++++++++++------------------
 1 file changed, 18 insertions(+), 18 deletions(-)

diff --git a/drivers/staging/vt6655/rxtx.c b/drivers/staging/vt6655/rxtx.c
index cc3b642ef8af..1704b63da2cd 100644
--- a/drivers/staging/vt6655/rxtx.c
+++ b/drivers/staging/vt6655/rxtx.c
@@ -102,7 +102,7 @@ static void s_vgenerate_tx_parameter(struct vnt_private *p_device,
 				     void *pv_rts,
 				     void *pv_cts,
 				     unsigned int	cb_frame_size,
-				     bool bNeedACK,
+				     bool b_need_ack,
 				     unsigned int	uDMAIdx,
 				     void *psEthHeader,
 				     unsigned short wCurrentRate);
@@ -927,7 +927,7 @@ static void s_vFillCTSHead(struct vnt_private *p_device,
  *      pv_rts            - RTS Buffer
  *      pCTS            - CTS Buffer
  *      cb_frame_size     - Transmit Data Length (Hdr+Payload+FCS)
  *      bNeedACK        - If need ACK
  *      uDescIdx        - Desc Index
  *  Out:
  *      none
@@ -944,7 +944,7 @@ static void s_vgenerate_tx_parameter(struct vnt_private *p_device,
 				     void *pv_rts,
 				     void *pv_cts,
 				     unsigned int cb_frame_size,
-				     bool bNeedACK,
+				     bool b_need_ack,
 				     unsigned int uDMAIdx,
 				     void *psEthHeader,
 				     unsigned short wCurrentRate)
@@ -979,30 +979,30 @@ static void s_vgenerate_tx_parameter(struct vnt_private *p_device,
 							       cb_frame_size, wCurrentRate);
 			buf->rrv_time_a = vnt_rxtx_rsvtime_le16(p_device, by_pkt_type,
 								cb_frame_size,
-								wCurrentRate, bNeedACK);
+								wCurrentRate, b_need_ack);
 			buf->rrv_time_b = vnt_rxtx_rsvtime_le16(p_device, PK_TYPE_11B,
 								cb_frame_size,
 								p_device->byTopCCKBasicRate,
-								bNeedACK);
+								b_need_ack);
 
-			s_v_fill_rts_head(p_device, by_pkt_type, pv_rts, cb_frame_size, bNeedACK,
+			s_v_fill_rts_head(p_device, by_pkt_type, pv_rts, cb_frame_size, b_need_ack,
 					  b_dis_crc, psEthHeader, wCurrentRate, by_fb_option);
 		} else {/* RTS_needless, PCF mode */
 			struct vnt_rrv_time_cts *buf = pv_rrv_time;
 
 			buf->rrv_time_a = vnt_rxtx_rsvtime_le16(p_device, by_pkt_type,
 								cb_frame_size,
-								wCurrentRate, bNeedACK);
+								wCurrentRate, b_need_ack);
 			buf->rrv_time_b = vnt_rxtx_rsvtime_le16(p_device, PK_TYPE_11B,
 								cb_frame_size,
 								p_device->byTopCCKBasicRate,
-								bNeedACK);
+								b_need_ack);
 			buf->cts_rrv_time_ba = get_rtscts_time(p_device, 3, by_pkt_type,
 							       cb_frame_size, wCurrentRate);
 
 			/* Fill CTS */
 			s_vFillCTSHead(p_device, uDMAIdx, by_pkt_type, pv_cts, cb_frame_size,
-				       bNeedACK, b_dis_crc, wCurrentRate, by_fb_option);
+				       b_need_ack, b_dis_crc, wCurrentRate, by_fb_option);
 		}
 	} else if (by_pkt_type == PK_TYPE_11A) {
 		if (pv_rts) {/* RTS_need, non PCF mode */
@@ -1011,16 +1011,16 @@ static void s_vgenerate_tx_parameter(struct vnt_private *p_device,
 			buf->rts_rrv_time = get_rtscts_time(p_device, 2, by_pkt_type, cb_frame_size,
 							    wCurrentRate);
 			buf->rrv_time = vnt_rxtx_rsvtime_le16(p_device, by_pkt_type, cb_frame_size,
-							      wCurrentRate, bNeedACK);
+							      wCurrentRate, b_need_ack);
 
 			/* Fill RTS */
-			s_v_fill_rts_head(p_device, by_pkt_type, pv_rts, cb_frame_size, bNeedACK,
+			s_v_fill_rts_head(p_device, by_pkt_type, pv_rts, cb_frame_size, b_need_ack,
 					  b_dis_crc, psEthHeader, wCurrentRate, by_fb_option);
 		} else if (!pv_rts) {/* RTS_needless, non PCF mode */
 			struct vnt_rrv_time_ab *buf = pv_rrv_time;
 
 			buf->rrv_time = vnt_rxtx_rsvtime_le16(p_device, PK_TYPE_11A, cb_frame_size,
-							      wCurrentRate, bNeedACK);
+							      wCurrentRate, b_need_ack);
 		}
 	} else if (by_pkt_type == PK_TYPE_11B) {
 		if (pv_rts) {/* RTS_need, non PCF mode */
@@ -1029,16 +1029,16 @@ static void s_vgenerate_tx_parameter(struct vnt_private *p_device,
 			buf->rts_rrv_time = get_rtscts_time(p_device, 0, by_pkt_type, cb_frame_size,
 							    wCurrentRate);
 			buf->rrv_time = vnt_rxtx_rsvtime_le16(p_device, PK_TYPE_11B, cb_frame_size,
-							      wCurrentRate, bNeedACK);
+							      wCurrentRate, b_need_ack);
 
 			/* Fill RTS */
-			s_v_fill_rts_head(p_device, by_pkt_type, pv_rts, cb_frame_size, bNeedACK,
+			s_v_fill_rts_head(p_device, by_pkt_type, pv_rts, cb_frame_size, b_need_ack,
 					  b_dis_crc, psEthHeader, wCurrentRate, by_fb_option);
 		} else { /* RTS_needless, non PCF mode */
 			struct vnt_rrv_time_ab *buf = pv_rrv_time;
 
 			buf->rrv_time = vnt_rxtx_rsvtime_le16(p_device, PK_TYPE_11B, cb_frame_size,
-							      wCurrentRate, bNeedACK);
+							      wCurrentRate, b_need_ack);
 		}
 	}
 }
@@ -1065,7 +1065,7 @@ static unsigned int s_cbFillTxBufHead(struct vnt_private *p_device,
 	unsigned int uMACfragNum = 1;
 	unsigned int uPadding = 0;
 	unsigned int cbReqCount = 0;
-	bool bNeedACK = (bool)(fifo_ctl & FIFOCTL_NEEDACK);
+	bool b_need_ack = (bool)(fifo_ctl & FIFOCTL_NEEDACK);
 	bool bRTS = (bool)(fifo_ctl & FIFOCTL_RTS);
 	struct vnt_tx_desc *ptdCurr;
 	unsigned int cbHeaderLength = 0;
@@ -1229,10 +1229,10 @@ static unsigned int s_cbFillTxBufHead(struct vnt_private *p_device,
 
 	/* Fill FIFO,RrvTime,RTS,and CTS */
 	s_vgenerate_tx_parameter(p_device, by_pkt_type, tx_buffer_head, pv_rrv_time, pv_rts, pv_cts,
-				 cb_frame_size, bNeedACK, uDMAIdx, hdr, p_device->wCurrentRate);
+				 cb_frame_size, b_need_ack, uDMAIdx, hdr, p_device->wCurrentRate);
 	/* Fill DataHead */
 	uDuration = s_uFillDataHead(p_device, by_pkt_type, pvTxDataHd, cb_frame_size, uDMAIdx,
-				    bNeedACK, 0, 0, uMACfragNum, by_fb_option,
+				    b_need_ack, 0, 0, uMACfragNum, by_fb_option,
 				    p_device->wCurrentRate, is_pspoll);
 
 	hdr->duration_id = uDuration;
@@ -927,7 +927,7 @@ static void s_vFillCTSHead(struct vnt_private *p_device,
  *      pCTS            - CTS Buffer
  *      cb_frame_size     - Transmit Data Length (Hdr+Payload+FCS)
- *      bNeedACK        - If need ACK
+ *      b_need_ack        - If need ACK
  *      uDescIdx        - Desc Index
  *  Out:
-- 
2.34.1


  parent reply	other threads:[~2022-10-25 23:39 UTC|newest]

Thread overview: 25+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2022-10-25 23:36 [PATCH 00/17] staging: vt6655: a series of checkpatch fixes on the file: rxtx.c Tanjuate Brunostar
2022-10-25 23:36 ` [PATCH 01/17] staging: vt6655: changed variable names: wFB_Opt0 Tanjuate Brunostar
2022-10-26  2:46   ` Philipp Hortmann
2022-10-26  3:24   ` Philipp Hortmann
2022-10-25 23:36 ` [PATCH 02/17] staging: vt6655: changed variable names: s_vFillRTSHead Tanjuate Brunostar
2022-10-26  2:56   ` Philipp Hortmann
2022-10-26 13:52   ` Greg KH
2022-10-25 23:36 ` [PATCH 03/17] staging: vt6655: changed variable name: pDevice Tanjuate Brunostar
2022-10-26  3:03   ` Philipp Hortmann
2022-10-25 23:37 ` [PATCH 04/17] staging: vt6655: changed variable name: byPktType Tanjuate Brunostar
2022-10-25 23:37 ` [PATCH 05/17] staging: vt6655: changed variable name: pvRTS Tanjuate Brunostar
2022-10-26 13:51   ` Greg KH
2022-10-27  6:12     ` Tanju Brunostar
2022-10-25 23:37 ` [PATCH 06/17] staging: vt6655: changed variable name: cbFrameLength Tanjuate Brunostar
2022-10-25 23:37 ` [PATCH 07/17] staging: vt6655: changed variable name: b_need_ack Tanjuate Brunostar
2022-10-25 23:37 ` [PATCH 08/17] staging: vt6655: changed variable name: bDisCRC Tanjuate Brunostar
2022-10-25 23:37 ` [PATCH 09/17] staging: vt6655: changed variable name: byFBOption Tanjuate Brunostar
2022-10-25 23:37 ` [PATCH 10/17] staging: vt6655: changed variable name: s_vGenerateTxParameter Tanjuate Brunostar
2022-10-25 23:37 ` [PATCH 11/17] staging: vt6655: changed variable name: pvRrvTime Tanjuate Brunostar
2022-10-25 23:37 ` [PATCH 12/17] staging: vt6655: changed variable name: cbFrameSize Tanjuate Brunostar
2022-10-25 23:37 ` Tanjuate Brunostar [this message]
2022-10-25 23:37 ` [PATCH 14/17] staging: vt6655: changed variable name: uDMAIdx Tanjuate Brunostar
2022-10-25 23:37 ` [PATCH 15/17] staging: vt6655: changed variable name: psEthHeader Tanjuate Brunostar
2022-10-25 23:37 ` [PATCH 16/17] staging: vt6655: changed variable name: s_cbFillTxBufHead Tanjuate Brunostar
2022-10-25 23:37 ` [PATCH 17/17] staging: vt6655: changed variable name: pbyTxBufferAddr Tanjuate Brunostar

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=c41b74ed595c33c4d3385aa2ae638e337b26337e.1666740522.git.tanjubrunostar0@gmail.com \
    --to=tanjubrunostar0@gmail.com \
    --cc=gregkh@linuxfoundation.org \
    --cc=linux-kernel@vger.kernel.org \
    --cc=linux-staging@lists.linux.dev \
    --cc=outreachy@lists.linux.dev \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).